from word_creator import Word
from re import sub

class WordRenderer:

	@staticmethod
	def create_word(word):
		word_list = Word(word).get_word()
		result = ""
		for row in word_list:
			for item in row:
				result = "".join((result, str(item)))
			result = "\n".join((result, ""))
		return result

	def create_rendered_word(self, word, positive="1", negative="0"):
		result = self.create_word(word)
		result = sub(r"1", positive, result)
		result = sub(r"0", negative, result)
		return result

if __name__ == '__main__':
	renderer = WordRenderer()
	print renderer.create_word('HEY EVERYBODY')
	print renderer.create_rendered_word('HELLO FRIEND', "X", " ")
	print renderer.create_rendered_word('HEY EVERYBODY', "O", " ")
	print renderer.create_rendered_word('A B C D E F G', "O", " ")
	print renderer.create_rendered_word('H I J K L M N', "O", " ")
	print renderer.create_rendered_word('O P Q R S T U', "O", " ")
	print renderer.create_rendered_word('V W X Y Z', "O", " ")
	print renderer.create_rendered_word('da da da', "O", " ")
	print renderer.create_rendered_word('DANCE', ':boredparrot:', ':shuffleparrot:')


from letter_profiles import Letter

SPACE_CHARACTER = Letter(' ')()

class Word:

	word_prime = {'word': []}

	def __init__(self, word_string):
		self.word_prime['word'] = [list(bit) for bit in SPACE_CHARACTER]
		for char in word_string:
			char = Letter(char)
			char_list = char()
			for idx, row in enumerate(char_list):
				self.word_prime.get('word')[idx].extend(row)
			for idx, row in enumerate(SPACE_CHARACTER):
				self.word_prime.get('word')[idx].extend(row)

	def get_word(self):
		return self.word_prime.get('word')

if __name__ == '__main__':
	w = Word('HELLO')
	print w.get_word()


from word_renderer import WordRenderer
import click

@click.command()
@click.option('--text', help='Text to asciify')
@click.option('--pos', default='X', help='Character that serves as positive space')
@click.option('--neg', default=' ', help='Character that serves as negative space')
def main(text, pos, neg):
	renderer = WordRenderer()
	print renderer.create_rendered_word(text, pos, neg)

if __name__ == '__main__':
	main()


from setuptools import setup, find_packages

setup(
    name="asciify",
    packages=find_packages(),
    version="0.0.1",
    description="Fun little project",
    long_description="",
    url="https://github.com/paolopaolopaolo/ascii_text_generator/",
    license="GNU",
    author="Dean Mercado",
    author_email="dpaolomercado@gmail.com",
    setup_requires=[
        "click==6.6"
    ],
    install_requires=[
        "click==6.6"
    ],
    test_suite="",
    entry_points={
        "console_scripts": [
            "asciify=asciify:main",
        ]
    },
    classifiers=[
        "Development Status :: 3 - Alpha",
    ]
)